@@ -3,6 +3,7 @@ import hildon
 import osmgpsmap
 import gobject
 import os
+import evolution
 
 
 class DetailsWindow(hildon.StackableWindow):
@@ -59,7 +60,7 @@ class DetailsWindow(hildon.StackableWindow):
                             break
             except:
                 pass
-            
+
         self.details_share = "%slat/lon: %f,%f " % (self.details_share, point[0], point[1])
 
 
@@ -100,7 +101,7 @@ class DetailsWindow(hildon.StackableWindow):
 
         bt_mapa = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"Mapa")
-        bt_mapa.connect("clicked", self.on_mapa)
+        bt_mapa.connect("clicked", self.on_mapa, point[0], point[1])
         self.bt_hbox.pack_start( bt_mapa, True)
 
 
@@ -117,8 +118,8 @@ class DetailsWindow(hildon.StackableWindow):
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"Route")
             bt_route.connect("clicked",self.on_route_to_it,point[0],point[1])
             self.bt_hbox.pack_start( bt_route, True)
-            
-        
+
+
 
 
         vbox.pack_start(self.bt_hbox,False)
@@ -151,21 +152,27 @@ class DetailsWindow(hildon.StackableWindow):
 
                 bt_phone = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"%s" % ref_downloader.ref_result[2])
-                
+
                 self.details_share = "%stel: %s; %s" % (self.details_share, ref_downloader.ref_result[2], ref_downloader.ref_result[1])
-                
+
                 bt_phone.connect("clicked",self.on_call_clicked, ref_downloader.ref_result[2] )
                 hbox.pack_start( bt_phone, True)
 
                 tlldbox.pack_start( hbox, False)
 
                 tlldbox.show_all()
-                
-                
+
+
                 if self.osmMapa.send_to_contact_present():
                     self.bt_hbox.pack_start(self.osmMapa.send_to_contact_dialog(self.details_share), False)
 
-                
+                bt_addContact = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                               hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add Contact")
+                bt_addContact.connect("clicked",self.on_bt_addContact,ref_downloader.ref_result)
+                self.bt_hbox.pack_start( bt_addContact, True)
+                bt_addContact.show_all()
+
+
             except Exception, e:
                 print "add reference error",e
 
@@ -173,6 +180,21 @@ class DetailsWindow(hildon.StackableWindow):
         #os.system(  "dbus-send --system --dest=com.nokia.csd.Call --type=method_call --print-reply /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0 &" % tel )
         os.system(  "dbus-send --system --type=method_call --print-reply --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0" % tel.replace(" ", "") )
 
+    def on_bt_addContact(self,w, store):
+        print "--- add concat --- "
+        addresses = evolution.ebook.open_addressbook('default')
+        c = evolution.ebook.EContact("""BEGIN:VCARD
+VERSION:3.0
+FN:"""+store[0]+"""
+TEL;TYPE=CELL:"""+store[2].replace(" ","")+"""
+NOTE:add by yosmapa
+ADR:"""+store[1]+""";;;;;;
+END:VCARD
+BEGIN:VCARD""")
+        addresses.add_contact(c)
+        self.osmMapa.showBanner("Contact added.")
+        print "--- add concat DONE --- "
+
     def on_route_to_it(self, w, lat, lon):
         p = None
         for plugin in self.osmMapa.plugins_list:
@@ -200,7 +222,8 @@ class DetailsWindow(hildon.StackableWindow):
     def on_map_clicked(self,osm,event, lat, lon):
         osm.set_center_and_zoom( lat, lon, 16 )
 
-    def on_mapa(self,w):
+    def on_mapa(self,w,lat,lon):
+        self.osmMapa.osm.set_center_and_zoom( lat, lon, 16 )
         self.destroy()
 
 
