@@ -388,7 +388,7 @@ class google_routesearch:
         self.osmMapa = osmMapa
 
 
-        self.ico = "route.png"
+        self.ico = "ico_navi2_32_32.png"
         self.ui_menu_main = 0
         self.ui_menu_left = 1
         self.ui_stackable = 1
