@@ -516,7 +516,8 @@ class UI(hildon.StackableWindow):
         w.add( v )
         w.show_all()
 
-
+    def build_details(self, point):
+        w = DetailsWindow( self, point, CONFIG )
 
 
     # ------------------ SMS
